//+------------------------------------------------------------------+
//|                                                 Price lines.mq4  |
//|                                            created by Kamil2079  |
//+------------------------------------------------------------------+

#property indicator_chart_window

/*
This indicator draw 5 closest price lines and display numbers in the
lower right corner about:
- how far is current price from the high (Hi) 
- and from the low (Lo) 
of current (and previous) candle.
*/

// Warning values for 5m and 4h chart. If distance is bigger than this
// values, number is red and bold.
extern int Max4h = 50; //50pips         
extern int Max5m = 20; //20 pips  
     
extern color Line_Color = SeaGreen;

bool firsttime = true;
int fontsize = 10;
int corner = 3;
int xdispl = 5;
int ydispl = 1;
int Max;

int init()
{
   ObjectCreate("Lo", OBJ_LABEL, 0, 0, 0);
   ObjectSet("Lo", OBJPROP_CORNER, corner);
   ObjectSet("Lo", OBJPROP_XDISTANCE, xdispl);
   ObjectSet("Lo", OBJPROP_YDISTANCE, ydispl+15);
   
   ObjectCreate("Hi", OBJ_LABEL, 0, 0, 0);
   ObjectSet("Hi", OBJPROP_CORNER, corner);
   ObjectSet("Hi", OBJPROP_XDISTANCE, xdispl);
   ObjectSet("Hi", OBJPROP_YDISTANCE, ydispl+30);
   
   if(Period() == 5) Max = Max5m;
   else              Max = Max4h;
}

int deinit()
  {
    ObjectDelete("T2 Price");
    ObjectDelete("T1 Price");
    ObjectDelete("M Price");
    ObjectDelete("B1 Price");
    ObjectDelete("B2 Price");
    
    ObjectDelete("Hi");
    ObjectDelete("Lo");
   }

int start()
{
   double T2,T1,MP,B1,B2,price;   

// Hi Lo part
   int LowPrice = MathRound((Ask - Low[0]) * 10000);
   int HiPrice =  MathRound((High[0]-Bid) * 10000);
   int PrevLowPrice = MathRound((Ask - Low[1]) * 10000);
   int PrevHiPrice =  MathRound((High[1]-Bid) * 10000);
   color HiLoColor;
   string font; 
 
   if(HiPrice > Max)
   { 
      HiLoColor = Red;  
      font = "Tahoma Bold";
   }
   else 
   {
      HiLoColor = Black; 
      font = "Tahoma";
   }
   ObjectSetText("Hi","Hi: "+HiPrice+" ("+PrevHiPrice+")",fontsize,font,HiLoColor);
 
   if(LowPrice > Max)
   {
      HiLoColor = Red;
      font = "Tahoma Bold";
   }
   else 
   {
      HiLoColor = Black;
      font = "Tahoma";
   }
   ObjectSetText("Lo","Lo: "+LowPrice+" ("+PrevLowPrice+")",fontsize,font,HiLoColor);

// Price lines part
    if(!firsttime)
       if(Volume[0]>1) return; 
    firsttime = false;
    
    price = MathRound(Open[0] * 100)/100;
    T2 = price + 0.02;
    T1 = price + 0.01;
    MP = price;
    B1 = price - 0.01;
    B2 = price - 0.02;

    if(ObjectFind("T2 Price") != 0)
      {
        ObjectCreate("T2 Price", OBJ_HLINE, 0, Time[0], T2);
        ObjectSet("T2 Price", OBJPROP_COLOR, Line_Color);
      }
    else
      {
        ObjectMove("T2 Price", 0, Time[0], T2);
      }
      
    if(ObjectFind("T1 Price") != 0)
      {
        ObjectCreate("T1 Price", OBJ_HLINE, 0, Time[0], T1);
        ObjectSet("T1 Price", OBJPROP_COLOR, Line_Color);
      }
    else
      {
        ObjectMove("T1 Price", 0, Time[0], T1);
      }
        
    if(ObjectFind("M Price") != 0)
      {
        ObjectCreate("M Price", OBJ_HLINE, 0, Time[0], MP);
        ObjectSet("M Price", OBJPROP_COLOR, Line_Color);
      }
    else
      {
        ObjectMove("M Price", 0, Time[0], MP);
      }
       
    if(ObjectFind("B1 Price") != 0)
      {
        ObjectCreate("B1 Price", OBJ_HLINE, 0, Time[0], B1);
        ObjectSet("B1 Price", OBJPROP_COLOR, Line_Color);
      }
    else
      {
        ObjectMove("B1 Price", 0, Time[0], B1);
      }
    
    if(ObjectFind("B2 Price") != 0)
      {
        ObjectCreate("B2 Price", OBJ_HLINE, 0, Time[0], B2);
        ObjectSet("B2 Price", OBJPROP_COLOR, Line_Color);
      }
    else
      {
        ObjectMove("B2 Price", 0, Time[0], B2);
      }  
return(0);
}